==> jc-1.4.0.tar.gz: gnu/java/rmi/server/RMIDefaultSocketFactory.h <==
// public class gnu.java.rmi.server.RMIDefaultSocketFactory

// class file dependencies
// @dep_class 344052e1c32016aa gnu_java_rmi_server_RMIDefaultSocketFactory
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ef0c14a2320dd9c java_rmi_server_RMISocketFactory

// header file dependencies
// @dep_header java_rmi_server_RMISocketFactory

#include "java/rmi/server/RMISocketFactory.h"

#ifndef _JC_gnu_java_rmi_server_RMIDefaultSocketFactory_H_
#define _JC_gnu_java_rmi_server_RMIDefaultSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_net_Socket$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_refs	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_nonrefs	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$refs	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$refs;
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$nonrefs	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object;

typedef const struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vmethods	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtable	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *);

// Virtual methods
extern struct _jc_java_net_ServerSocket$object *_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method$createServerSocket$b3153da56a9db8c5(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *, jint);
extern struct _jc_java_net_Socket$object *_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method$createSocket$0d93b2802005a3fd(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *, struct _jc_java_lang_String$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method_info$createServerSocket$b3153da56a9db8c5;
extern _jc_method _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method_info$createSocket$0d93b2802005a3fd;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vmethods {
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$b3153da56a9db8c5)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *, jint);
	struct _jc_java_net_Socket$object	*(*createSocket$0d93b2802005a3fd)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *, struct _jc_java_lang_String$object *, jint);
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMISocketFactory$vmethods	java_rmi_server_RMISocketFactory;
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vmethods	gnu_java_rmi_server_RMIDefaultSocketFactory;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$refs {
    _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_refs	gnu_java_rmi_server_RMIDefaultSocketFactory;
    _jc_java_rmi_server_RMISocketFactory$sub_refs	java_rmi_server_RMISocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMISocketFactory$sub_nonrefs	java_rmi_server_RMISocketFactory;
    _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_nonrefs	gnu_java_rmi_server_RMIDefaultSocketFactory;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object {
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIDefaultSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIDefaultSocketFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/RMIDefaultSocketFactory.h <==
// public class gnu.java.rmi.server.RMIDefaultSocketFactory

// class file dependencies
// @dep_class 344052e1c32016aa gnu_java_rmi_server_RMIDefaultSocketFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ef0c14a2320dd9c java_rmi_server_RMISocketFactory

// header file dependencies
// @dep_header java_rmi_server_RMISocketFactory

#include "java/rmi/server/RMISocketFactory.h"

#ifndef _JC_gnu_java_rmi_server_RMIDefaultSocketFactory_H_
#define _JC_gnu_java_rmi_server_RMIDefaultSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_net_Socket$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_refs	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_nonrefs	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$refs	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$refs;
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$nonrefs	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object;

typedef const struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vmethods	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtable	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_net_ServerSocket$object *_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method$createServerSocket$b3153da56a9db8c5(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_net_Socket$object *_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method$createSocket$0d93b2802005a3fd(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method_info$createServerSocket$b3153da56a9db8c5;
extern _jc_method _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$method_info$createSocket$0d93b2802005a3fd;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vmethods {
	struct _jc_java_net_ServerSocket$object	*(*createServerSocket$b3153da56a9db8c5)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_net_Socket$object	*(*createSocket$0d93b2802005a3fd)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RMISocketFactory$vmethods	java_rmi_server_RMISocketFactory;
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vmethods	gnu_java_rmi_server_RMIDefaultSocketFactory;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$refs {
    _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_refs	gnu_java_rmi_server_RMIDefaultSocketFactory;
    _jc_java_rmi_server_RMISocketFactory$sub_refs	java_rmi_server_RMISocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RMISocketFactory$sub_nonrefs	java_rmi_server_RMISocketFactory;
    _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$sub_nonrefs	gnu_java_rmi_server_RMIDefaultSocketFactory;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$object {
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIDefaultSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$vtype _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIDefaultSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIDefaultSocketFactory$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIDefaultSocketFactory_H_ */
